@@ -9,7 +9,6 @@ use windows::Win32::Globalization::{MultiByteToWideChar, WideCharToMultiByte, CP
 use windows::core::{HRESULT, Error};
 
 use std::ptr;
-use std::env;
 use std::sync::mpsc;
 use std::thread;
 use std::time::Duration;
@@ -549,16 +548,16 @@ impl PTYProcess {
         self.process = process;
         self.close_process = close_process;
 
-        if env::var_os("CONPTY_CI").is_some() {
-            // For some reason, the CI requires a flush of the handle before
-            // reading from a thread.
-            let result = read(4096, true, self.conout, false).unwrap();
-            println!("{:?}", result);
-            let result = read(4096, true, self.conout, false).unwrap();
-            println!("{:?}", result);
-            let res: Result<u32, OsString> = self.write(OsString::from("\r\n\r\n"));
-            res.unwrap();
-        }
+        // if env::var_os("CONPTY_CI").is_some() {
+        //     // For some reason, the CI requires a flush of the handle before
+        //     // reading from a thread.
+        //     let result = read(4096, true, self.conout, false).unwrap();
+        //     println!("{:?}", result);
+        //     let result = read(4096, true, self.conout, false).unwrap();
+        //     println!("{:?}", result);
+        //     let res: Result<u32, OsString> = self.write(OsString::from("\r\n\r\n"));
+        //     res.unwrap();
+        // }
 
         self.reader_process_out.send(Some(process)).unwrap();
         unsafe {
