@@ -25,19 +25,23 @@ impl PTYImpl for WinPTY {
         Err(OsString::from("winpty_rs was compiled without WinPTY enabled"))
     }
 
-    fn is_eof(&mut self) -> Result<bool, OsString> {
+    fn is_eof(&self) -> Result<bool, OsString> {
         Err(OsString::from("winpty_rs was compiled without WinPTY enabled"))
     }
 
-    fn get_exitstatus(&mut self) -> Result<Option<u32>, OsString> {
+    fn get_exitstatus(&self) -> Result<Option<u32>, OsString> {
         Err(OsString::from("winpty_rs was compiled without WinPTY enabled"))
     }
 
-    fn is_alive(&mut self) -> Result<bool, OsString> {
+    fn is_alive(&self) -> Result<bool, OsString> {
         Err(OsString::from("winpty_rs was compiled without WinPTY enabled"))
     }
 
     fn get_pid(&self) -> u32 {
         0
     }
+
+    fn get_fd(&self) -> isize {
+        -1
+    }
 }
